@@ -7,41 +7,66 @@ OC.L10N.register(
     "Open »%s«" : "Opna »%s«",
     "Cheers!" : "Tudelu!",
     "Calendar" : "Kalender",
+    "Prepare for %s" : "Klargjer for %s",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Veke",
     "Month" : "Månad",
-    "Download" : "Last ned",
+    "Year" : "År",
+    "Copy link" : "Kopier lenkje",
+    "Edit" : "Rediger",
     "Delete" : "Slett",
+    "New calendar" : "Ny kalender",
+    "Export" : "Eksporter",
+    "Empty trash bin" : "Tøm søppel korg",
+    "Name" : "Namn",
+    "Deleted" : "Sletta",
+    "Restore" : "Gjenopprett",
+    "Delete permanently" : "Slett for godt",
     "Share link" : "Del lenkje",
     "can edit" : "kan endra",
-    "New calendar" : "Ny kalender",
-    "Cancel" : "Avbryt",
-    "Actions" : "Handlingar",
-    "Email" : "E-post",
-    "Unknown" : "Ukjend",
-    "Repeat" : "Gjenta",
     "Save" : "Lagre",
+    "Cancel" : "Avbryt",
+    "List view" : "Liste visning",
+    "Actions" : "Handlingar",
+    "Update" : "Oppdater",
+    "Location" : "Stad",
+    "Description" : "Skildring",
+    "to" : "til",
+    "Add" : "Legg til",
+    "Monday" : "Måndag",
+    "Tuesday" : "Tysdag",
+    "Wednesday" : "Onsdag",
+    "Thursday" : "Torsdag",
+    "Friday" : "Fredag",
+    "Saturday" : "Laurdag",
+    "Sunday" : "Søndag",
+    "Your email address" : "Di epost-adresse",
+    "Email" : "E-post",
+    "days" : "dagar",
+    "Delete file" : "Slett fil",
+    "Unknown" : "Ukjend",
+    "Tentative" : "Førebels",
+    "Attendees" : "Deltakarar",
+    "Repeat" : "Gjenta",
     "never" : "aldri",
     "after" : "etter",
-    "Monday" : "Måndag",
-    "More" : "Meir",
-    "Update" : "Oppdater",
+    "Room type" : "Romtype",
     "Global" : "Global",
     "Personal" : "Personleg",
-    "Details" : "Detaljar",
-    "Attendees" : "Deltakarar",
+    "Edit event" : "Rediger hending",
     "Close" : "Lukk",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
+    "second" : "andre",
+    "last" : "siste",
+    "Meeting room" : "Møterom",
+    "Other" : "Anna",
     "When shared show full event" : "Når delt, vis heile hendinga",
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
-    "Location" : "Stad",
-    "Description" : "Skildring",
     "Status" : "Status",
     "Confirmed" : "Stadfesta",
-    "Tentative" : "Førebels",
-    "Mail" : "Post"
+    "Details" : "Detaljar"
 },
 "nplurals=2; plural=(n != 1);");
